## 0.9.5 (2022-07-04)

### Refactor

- complete refactor to style i use in the toolboxes plus several fixes
- removed __future__

## 0.9.4 (2022-04-16)

### Fix

- removed filelike library as a dependency
- **setup.py**: fixed location of scripts and packages in setup.py

## 0.9.3 (2022-04-16)

### Fix

- **2to3**: edited to support python 3, no longer supporting python 2
